@@ -144,6 +144,24 @@ pub fn yank_note(index: &u16) -> IoResult {
     Ok(())
 }
 
+pub fn backup_data_file(dest_path: &mut PathBuf) -> IoResult {
+    if !check_if_file_exists() {
+        print_no_notes_msg();
+        return Ok(());
+    }
+    if !dest_path.is_dir() {
+        return Err(ClapIoError::from(format!(
+            "Backup of data file failed: {}",
+            "destination path does not exist"
+        )));
+    }
+    dest_path.push(format!("backup-{}-{}", get_date(), get_filename()));
+    let success_string = format!("backup to {:#?} complete", &dest_path);
+    fs::copy(get_file_path(), dest_path)?;
+    println!("{}", success_string);
+    Ok(())
+}
+
 fn overwrite_entries_to_file(entries: Entries) -> IoResult {
     let all_entries_to_str = entries.into_output_string();
     write_raw_text_to_file(&all_entries_to_str)?;
@@ -187,11 +205,19 @@ fn create_dir_if_none_exists() -> io::Result<()> {
 
 fn get_file_path() -> PathBuf {
     let mut path = get_dir_path();
-    let filename = "notes.txt";
+    let filename = get_filename();
     path.push(PathBuf::from(filename));
     path
 }
 
+fn get_date() -> String {
+    format!("{}", chrono::offset::Local::now())
+}
+
+fn get_filename() -> &'static str {
+    "notes.txt"
+}
+
 fn get_dir_path() -> PathBuf {
     let dir_path_str = "~/.config/post/";
     PathBuf::from(shellexpand::tilde(dir_path_str).to_string())
